import { createCatalog } from '../util/createCatalog.mjs';
import { buildURL } from '../util/formatterRepositoryFileNameUrl.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { readFile } from '../util/readFile.mjs';
import { wgetAsync } from '../util/wget.mjs';

const getRemoteContentToBuild = async ({ config, snpObject, }) => {
    try {
        const contentUrl = buildURL({
            baseURL: config.remoteRootRepositoryUrl,
            relativePaths: [snpObject.SNPSuffixFileName],
        });
        if (!(await isFileOrFolderExists(config.temporaryFolder))) {
            await createCatalog(config.temporaryFolder);
        }
        return await wgetAsync(contentUrl, config.temporaryFolder).then(async (remoteContent) => {
            return remoteContent;
        });
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
};
const getContentToBuild = async (snpSetObject) => {
    const { defaultFile, customFile, extendFile } = snpSetObject;
    if (snpSetObject &&
        [defaultFile.isCreated, customFile?.isCreated, extendFile?.isCreated].some((data) => data !== false)) {
        if (customFile?.isCreated) {
            const contentCustomFile = await readFile(customFile?.path || '');
            if (contentCustomFile.length) {
                return await readFile(customFile?.path || '');
            }
        }
        if (extendFile?.isCreated) {
            const contentExtendFile = await readFile(extendFile?.path || '');
            if (contentExtendFile.length) {
                return (await readFile(defaultFile.path || '')) + '\n' + (await readFile(extendFile.path || ''));
            }
        }
        if (defaultFile.isCreated) {
            return await readFile(defaultFile.path || '');
        }
    }
    else {
        return null;
    }
};

export { getContentToBuild, getRemoteContentToBuild };
