import path__default from 'path';
import { formatSnp } from '../feature/formatSnp.mjs';
import { updateDetailsFileMapConfig2 } from '../feature/updateFileMapConfig.mjs';
import { createPath } from './createPath.mjs';
import { debugFunction } from './debugFunction.mjs';
import { getRealFileName } from './getRealFileName.mjs';
import { getRealFilePath } from './getRealFilePath.mjs';
import { parseJSON } from './parseJSON.mjs';
import { readFile } from './readFile.mjs';

async function prepareBaseSnpFileMap(config) {
    debugFunction(config.isDebug, 'start', '[INIT] prepareBaseSnpFileMap');
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    try {
        if (snpFileMapConfig.snpFileMap && snpFileMapConfig.fileMap) {
            for (const SNPSuffixFileName of snpFileMapConfig.fileMap) {
                const realFileName = getRealFileName({ config, contentToCheck: [SNPSuffixFileName] })[0];
                const realFilePath = getRealFilePath({ config, SNPSuffixFileName });
                const SNPKeySuffix = formatSnp(SNPSuffixFileName, 'key');
                if (snpFileMapConfig.snpFileMap) {
                    if (!snpFileMapConfig.snpFileMap[realFilePath]) {
                        snpFileMapConfig = await updateDetailsFileMapConfig2({
                            snpFileMapConfig,
                            config,
                            operation: 'createRealFileName',
                            realFilePath,
                        });
                    }
                    if (snpFileMapConfig.snpFileMap && !snpFileMapConfig.snpFileMap[realFilePath]['_']) {
                        const filePath = createPath([
                            config.projectCatalog,
                            SNPSuffixFileName.replace(config.templateCatalogName, ''),
                        ]);
                        const directoryPath = path__default.dirname(filePath);
                        const originalFilePath = path__default.join(directoryPath, realFileName);
                        snpFileMapConfig = await updateDetailsFileMapConfig2({
                            snpFileMapConfig,
                            config,
                            operation: 'addConfigSuffixFile',
                            SNPKeySuffix: '_',
                            isCreated: false,
                            path: originalFilePath,
                            realFilePath,
                            realPath: createPath([config.projectCatalog, realFileName]),
                            templateVersion: snpFileMapConfig.templateVersion,
                        });
                    }
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        snpFileMapConfig,
                        config,
                        operation: 'addConfigSuffixFile',
                        SNPKeySuffix,
                        SNPSuffixFileName,
                        isCreated: false,
                        path: createPath([config.snpCatalog, SNPSuffixFileName]),
                        realFilePath,
                        realPath: createPath([config.projectCatalog, realFileName]),
                        templateVersion: snpFileMapConfig.templateVersion,
                    });
                }
            }
        }
        debugFunction(config.isDebug, config, '[INIT] prepareBaseSnpFileMap');
        return config;
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
}

export { prepareBaseSnpFileMap };
