import path__default from 'path';
import { formatSnp } from '../feature/formatSnp.mjs';
import { updateDetailsFileMapConfig2 } from '../feature/updateFileMapConfig.mjs';
import { createPath } from './createPath.mjs';
import { debugFunction } from './debugFunction.mjs';
import { parseJSON } from './parseJSON.mjs';
import { readFile } from './readFile.mjs';

async function prepareExtraFile(config) {
    debugFunction(config.isDebug, 'start', '[INIT] prepareExtraFile');
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    for (const SNPKeySuffix of config.availableSNPKeySuffix) {
        if (snpFileMapConfig.snpFileMap) {
            for (const [realFilePath, snpPathFileSet] of Object.entries(snpFileMapConfig.snpFileMap)) {
                if (!snpPathFileSet[SNPKeySuffix]) {
                    const snpSuffix = formatSnp(SNPKeySuffix, 'suffix');
                    const SNPSuffixFileName = path__default.basename(realFilePath + snpSuffix);
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        snpFileMapConfig,
                        config,
                        operation: 'addConfigSuffixFile',
                        SNPKeySuffix,
                        SNPSuffixFileName,
                        isCreated: false,
                        path: createPath([config.snpCatalog, SNPSuffixFileName]),
                        realFilePath,
                        realPath: createPath([config.projectCatalog, realFilePath]),
                        templateVersion: snpFileMapConfig.templateVersion,
                    });
                }
            }
        }
    }
    debugFunction(config.isDebug, config, '[INIT] prepareExtraFile - end');
    return config;
}

export { prepareExtraFile };
